import gym
from gym import spaces
from gym.utils import seeding

class GameEnv(gym.Env):
    metadata = {'render.modes': ['human']}

    def __init__(self):
        self.step_size = 50
        self.number_of_states = 100
        self.action_space = spaces.Discrete(2)
        self.seed()
        self._reset()
        self._owns_render = False

    def _step(self, action):
        '''
        Does one step. At the end of the game you are responsible yourself
        for calling env.reset().

        Accepts action 1 (make step) or 0 (stop game)

        Returns 4 values:
          observation The sum.
          reward The sum if smaller than 100 or zero if greater or equal.
          done (boolean, True for reaching terminal state)
          info (empty dictionary, ignore in this setting)

        For more details visit:
        https://github.com/openai/gym/blob/master/gym/core.py
        '''
        assert self.action_space.contains(action)

        if action == 1:
            self.number += self.np_random.randint(0, self.step_size);
            return self.number, 0, self.number >= self.number_of_states, {}
        else:
            return self.number, self.number, True, {}

    def _reset(self):
        self.number = self.np_random.randint(0, self.step_size);
        return self.number

    def _render(self, mode='human', close=False):
        '''
            Prints the situation to the terminal. Call env.render() any time
            you need to see the game. This method is useful for debugging.
            '''
        print("sum: " + str(self.number))

    def _seed(self, seed=None):
        self.np_random, seed = seeding.np_random(seed)
        return [seed]
